Search the catalog for datasets, data services and public services.
i14y_search_catalog(
query = NULL,
language = "de",
accessRights = NULL,
formats = NULL,
publishers = NULL,
statuses = NULL,
themes = NULL,
types = NULL,
page = NULL,
pageSize = NULL
)a tibble
string. The search query
string. The language to use for the search
vector of strings. Only results with one of the specified access rights (PUBLIC, NON_PUBLIC, RESTRICTED) are returned
vector of strings. Only results with at least one distribution providing one of the specified formats are returned
vector of strings. Only results with one of the specified publishers are returned
vector of strings. Only results with one of the specified registration statuses are returned
vector of strings. Only results corresponding to one of the specified themes are returned
vector of strings. Only results with one of the specified types (Dataset, DataService, PublicService) are returned
integer. The number of the result page to return
integer. The size of each result page
i14y_search_catalog(query = "noga")
Run the code above in your browser using DataLab